SerialNumber

Struct SerialNumber 

pub struct SerialNumber(pub u32);
Encapsulates a zone’s serial number.

SerialNumber uses sequence space arithmetic, defined in RFC 1982. Sequence space arithmetic defines the addition and comparison operations such that the serial number wraps on overflow while maintaining an intuitive and well defined meaning for the operations’ results.

Examples

use sparkle::SerialNumber;

let x = SerialNumber(0);
assert!(x < x + SerialNumber(1));

let x = SerialNumber(0x_ffff_ffff);
assert!(x < x + SerialNumber(1));

Tuple Fields

0: u32

Implementations